@@ -21,12 +21,15 @@ from itertools import izip_longest
 from argparse import ArgumentParser, FileType
 from types import TypeType
 from types import FileType as BaseFileType
+from ConfigParser import SafeConfigParser
 
 # do not remove, really
 from logging import INFO, WARN, ERROR #@UnusedImport
 from sys import stdin, stdout, stderr #@UnusedImport
 
 
+__defcfg__ = "/dev/null"
+
 __deflog__ = {"ls":stderr, # log stream
               "ll":"info", # log level
               "lf":"tab", # log format
@@ -85,10 +88,52 @@ class task(object):
     __funcs = {}
 
     @staticmethod
-    def _makelgr(args):
-        logstream = args.pop("ls")
-        loglevel = getattr(logging, args.pop("ll").upper())
-        logformat = __logforms__[args.pop("lf")]
+    def _makecfg(args):
+        cfg = args.pop("config")
+        parser = SafeConfigParser()
+        parser.readfp(cfg)
+        return parser
+
+    @staticmethod
+    def _makelgr(args, cfg):
+        # default arguments
+        defargs = {"level":__deflog__["ll"],
+                   "stream":__deflog__["ls"],
+                   "format":__deflog__["lf"]
+                   }
+        # config file arguments
+        cfgargs = {}
+        if cfg.has_section("log"):
+            for name in ("level", "stream", "format"):
+                if cfg.has_option("log", name):
+                    value = cfg.get("log", name)
+                    # manual type corrections
+                    if name in ("stream",):
+                        value = open(value, "a+")
+                    cfgargs[name] = value
+                else:
+                    cfgargs[name] = None
+        # command line arguments
+        # these are set to defaults by argparse
+        linargs = {"level":args.pop("ll"),
+                   "stream":args.pop("ls"),
+                   "format":args.pop("lf")
+                   }
+        finargs = {}
+        for key in ("level", "stream", "format"):
+            # default
+            finargs[key] = defargs[key]
+            # config if set
+            if cfgargs[key]:
+                finargs[key] = cfgargs[key]
+            # linargs if set
+            if linargs[key] != defargs[key]:
+                finargs[key] = linargs[key]
+        # prepare options
+        logstream = finargs["stream"]
+        loglevel = getattr(logging, finargs["level"].upper())
+        logformat = __logforms__[finargs["format"]]
+        # make logger
         lgr = logging.getLogger("moke")
         lgr.setLevel(loglevel)
         sh = logging.StreamHandler(stream=logstream)
@@ -144,6 +189,9 @@ class task(object):
         main_parser = ArgumentParser()
 
         # global options
+        main_parser.add_argument("-config", type=file_r, default=__defcfg__, 
+                                 help="(file_r) [default: None] configuration file")
+        
         main_parser.add_argument("-ls", type=file_a,
             default=__deflog__["ls"],
             help="(file_a) [default: %s] logging stream" % __deflog__["ls"].name)
@@ -154,8 +202,8 @@ class task(object):
 
         main_parser.add_argument("-lf", type=str,
             default=__deflog__["lf"], choices=("tab",),
-            help="(str) [default: %s] logging format" % __deflog__["lf"] )
-
+            help="(str) [default: %s] logging format" % __deflog__["lf"])
+        
         # subcommand options
         sub_parsers = None
         for name, func in cls.__funcs.iteritems():
@@ -234,7 +282,8 @@ class task(object):
     def _callfunc(cls, args):
         # get function and logger
         func = args.pop("func")
-        lgr = cls._makelgr(args)
+        cfg = cls._makecfg(args)
+        lgr = cls._makelgr(args, cfg)
         # where are we?
         cwd = os.getcwd()
         mokefile = os.path.abspath(os.path.join(cwd, sys.argv[0]))
